# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ScheduledSqlArgs', 'ScheduledSql']

@pulumi.input_type
class ScheduledSqlArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[str],
                 project: pulumi.Input[str],
                 schedule: pulumi.Input['ScheduledSqlScheduleArgs'],
                 scheduled_sql_configuration: pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs'],
                 scheduled_sql_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ScheduledSql resource.
        :param pulumi.Input[str] display_name: Task Display Name.
        :param pulumi.Input[str] project: Log project.
        :param pulumi.Input['ScheduledSqlScheduleArgs'] schedule: The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        :param pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs'] scheduled_sql_configuration: Task Configuration. See `scheduled_sql_configuration` below.
        :param pulumi.Input[str] scheduled_sql_name: Timed SQL name.
        :param pulumi.Input[str] description: Task Description.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "schedule", schedule)
        pulumi.set(__self__, "scheduled_sql_configuration", scheduled_sql_configuration)
        pulumi.set(__self__, "scheduled_sql_name", scheduled_sql_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        Task Display Name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        Log project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Input['ScheduledSqlScheduleArgs']:
        """
        The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: pulumi.Input['ScheduledSqlScheduleArgs']):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="scheduledSqlConfiguration")
    def scheduled_sql_configuration(self) -> pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs']:
        """
        Task Configuration. See `scheduled_sql_configuration` below.
        """
        return pulumi.get(self, "scheduled_sql_configuration")

    @scheduled_sql_configuration.setter
    def scheduled_sql_configuration(self, value: pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs']):
        pulumi.set(self, "scheduled_sql_configuration", value)

    @property
    @pulumi.getter(name="scheduledSqlName")
    def scheduled_sql_name(self) -> pulumi.Input[str]:
        """
        Timed SQL name.
        """
        return pulumi.get(self, "scheduled_sql_name")

    @scheduled_sql_name.setter
    def scheduled_sql_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "scheduled_sql_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Task Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ScheduledSqlState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input['ScheduledSqlScheduleArgs']] = None,
                 scheduled_sql_configuration: Optional[pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs']] = None,
                 scheduled_sql_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ScheduledSql resources.
        :param pulumi.Input[str] description: Task Description.
        :param pulumi.Input[str] display_name: Task Display Name.
        :param pulumi.Input[str] project: Log project.
        :param pulumi.Input['ScheduledSqlScheduleArgs'] schedule: The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        :param pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs'] scheduled_sql_configuration: Task Configuration. See `scheduled_sql_configuration` below.
        :param pulumi.Input[str] scheduled_sql_name: Timed SQL name.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if scheduled_sql_configuration is not None:
            pulumi.set(__self__, "scheduled_sql_configuration", scheduled_sql_configuration)
        if scheduled_sql_name is not None:
            pulumi.set(__self__, "scheduled_sql_name", scheduled_sql_name)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Task Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        Task Display Name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        Log project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['ScheduledSqlScheduleArgs']]:
        """
        The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['ScheduledSqlScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="scheduledSqlConfiguration")
    def scheduled_sql_configuration(self) -> Optional[pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs']]:
        """
        Task Configuration. See `scheduled_sql_configuration` below.
        """
        return pulumi.get(self, "scheduled_sql_configuration")

    @scheduled_sql_configuration.setter
    def scheduled_sql_configuration(self, value: Optional[pulumi.Input['ScheduledSqlScheduledSqlConfigurationArgs']]):
        pulumi.set(self, "scheduled_sql_configuration", value)

    @property
    @pulumi.getter(name="scheduledSqlName")
    def scheduled_sql_name(self) -> Optional[pulumi.Input[str]]:
        """
        Timed SQL name.
        """
        return pulumi.get(self, "scheduled_sql_name")

    @scheduled_sql_name.setter
    def scheduled_sql_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scheduled_sql_name", value)


class ScheduledSql(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[Union['ScheduledSqlScheduleArgs', 'ScheduledSqlScheduleArgsDict']]] = None,
                 scheduled_sql_configuration: Optional[pulumi.Input[Union['ScheduledSqlScheduledSqlConfigurationArgs', 'ScheduledSqlScheduledSqlConfigurationArgsDict']]] = None,
                 scheduled_sql_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a SLS Scheduled SQL resource. Scheduled SQL task.

        For information about SLS Scheduled SQL and how to use it, see [What is Scheduled SQL](https://www.alibabacloud.com/help/zh/sls/developer-reference/api-sls-2020-12-30-createscheduledsql).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_k_ie4_kv = alicloud.log.Project("defaultKIe4KV",
            description=f"{name}-{default['result']}",
            project_name=f"{name}-{default['result']}")
        default1_li9we = alicloud.log.Store("default1LI9we",
            hot_ttl=8,
            retention_period=30,
            shard_count=2,
            project_name=default_k_ie4_kv.project_name,
            logstore_name=f"{name}-{default['result']}")
        default_scheduled_sql = alicloud.sls.ScheduledSql("default",
            description="example-tf-scheduled-sql-0006",
            schedule={
                "type": "Cron",
                "time_zone": "+0700",
                "delay": 20,
                "cron_expression": "0 0/1 * * *",
            },
            display_name="example-tf-scheduled-sql-0006",
            scheduled_sql_configuration={
                "script": "* | select * from log",
                "sql_type": "searchQuery",
                "dest_endpoint": "ap-northeast-1.log.aliyuncs.com",
                "dest_project": "job-e2e-project-jj78kur-ap-southeast-1",
                "source_logstore": default1_li9we.logstore_name,
                "dest_logstore": "example-open-api02",
                "role_arn": "acs:ram::1395894005868720:role/aliyunlogetlrole",
                "dest_role_arn": "acs:ram::1395894005868720:role/aliyunlogetlrole",
                "from_time_expr": "@m-1m",
                "to_time_expr": "@m",
                "max_run_time_in_seconds": 1800,
                "resource_pool": "enhanced",
                "max_retries": 5,
                "from_time": 1713196800,
                "to_time": 0,
                "data_format": "log2log",
            },
            scheduled_sql_name=name,
            project=default_k_ie4_kv.project_name)
        ```

        ## Import

        SLS Scheduled SQL can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/scheduledSql:ScheduledSql example <project>:<scheduled_sql_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Task Description.
        :param pulumi.Input[str] display_name: Task Display Name.
        :param pulumi.Input[str] project: Log project.
        :param pulumi.Input[Union['ScheduledSqlScheduleArgs', 'ScheduledSqlScheduleArgsDict']] schedule: The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        :param pulumi.Input[Union['ScheduledSqlScheduledSqlConfigurationArgs', 'ScheduledSqlScheduledSqlConfigurationArgsDict']] scheduled_sql_configuration: Task Configuration. See `scheduled_sql_configuration` below.
        :param pulumi.Input[str] scheduled_sql_name: Timed SQL name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScheduledSqlArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a SLS Scheduled SQL resource. Scheduled SQL task.

        For information about SLS Scheduled SQL and how to use it, see [What is Scheduled SQL](https://www.alibabacloud.com/help/zh/sls/developer-reference/api-sls-2020-12-30-createscheduledsql).

        > **NOTE:** Available since v1.224.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        default_k_ie4_kv = alicloud.log.Project("defaultKIe4KV",
            description=f"{name}-{default['result']}",
            project_name=f"{name}-{default['result']}")
        default1_li9we = alicloud.log.Store("default1LI9we",
            hot_ttl=8,
            retention_period=30,
            shard_count=2,
            project_name=default_k_ie4_kv.project_name,
            logstore_name=f"{name}-{default['result']}")
        default_scheduled_sql = alicloud.sls.ScheduledSql("default",
            description="example-tf-scheduled-sql-0006",
            schedule={
                "type": "Cron",
                "time_zone": "+0700",
                "delay": 20,
                "cron_expression": "0 0/1 * * *",
            },
            display_name="example-tf-scheduled-sql-0006",
            scheduled_sql_configuration={
                "script": "* | select * from log",
                "sql_type": "searchQuery",
                "dest_endpoint": "ap-northeast-1.log.aliyuncs.com",
                "dest_project": "job-e2e-project-jj78kur-ap-southeast-1",
                "source_logstore": default1_li9we.logstore_name,
                "dest_logstore": "example-open-api02",
                "role_arn": "acs:ram::1395894005868720:role/aliyunlogetlrole",
                "dest_role_arn": "acs:ram::1395894005868720:role/aliyunlogetlrole",
                "from_time_expr": "@m-1m",
                "to_time_expr": "@m",
                "max_run_time_in_seconds": 1800,
                "resource_pool": "enhanced",
                "max_retries": 5,
                "from_time": 1713196800,
                "to_time": 0,
                "data_format": "log2log",
            },
            scheduled_sql_name=name,
            project=default_k_ie4_kv.project_name)
        ```

        ## Import

        SLS Scheduled SQL can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sls/scheduledSql:ScheduledSql example <project>:<scheduled_sql_name>
        ```

        :param str resource_name: The name of the resource.
        :param ScheduledSqlArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScheduledSqlArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 schedule: Optional[pulumi.Input[Union['ScheduledSqlScheduleArgs', 'ScheduledSqlScheduleArgsDict']]] = None,
                 scheduled_sql_configuration: Optional[pulumi.Input[Union['ScheduledSqlScheduledSqlConfigurationArgs', 'ScheduledSqlScheduledSqlConfigurationArgsDict']]] = None,
                 scheduled_sql_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScheduledSqlArgs.__new__(ScheduledSqlArgs)

            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if schedule is None and not opts.urn:
                raise TypeError("Missing required property 'schedule'")
            __props__.__dict__["schedule"] = schedule
            if scheduled_sql_configuration is None and not opts.urn:
                raise TypeError("Missing required property 'scheduled_sql_configuration'")
            __props__.__dict__["scheduled_sql_configuration"] = scheduled_sql_configuration
            if scheduled_sql_name is None and not opts.urn:
                raise TypeError("Missing required property 'scheduled_sql_name'")
            __props__.__dict__["scheduled_sql_name"] = scheduled_sql_name
        super(ScheduledSql, __self__).__init__(
            'alicloud:sls/scheduledSql:ScheduledSql',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            schedule: Optional[pulumi.Input[Union['ScheduledSqlScheduleArgs', 'ScheduledSqlScheduleArgsDict']]] = None,
            scheduled_sql_configuration: Optional[pulumi.Input[Union['ScheduledSqlScheduledSqlConfigurationArgs', 'ScheduledSqlScheduledSqlConfigurationArgsDict']]] = None,
            scheduled_sql_name: Optional[pulumi.Input[str]] = None) -> 'ScheduledSql':
        """
        Get an existing ScheduledSql resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Task Description.
        :param pulumi.Input[str] display_name: Task Display Name.
        :param pulumi.Input[str] project: Log project.
        :param pulumi.Input[Union['ScheduledSqlScheduleArgs', 'ScheduledSqlScheduleArgsDict']] schedule: The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        :param pulumi.Input[Union['ScheduledSqlScheduledSqlConfigurationArgs', 'ScheduledSqlScheduledSqlConfigurationArgsDict']] scheduled_sql_configuration: Task Configuration. See `scheduled_sql_configuration` below.
        :param pulumi.Input[str] scheduled_sql_name: Timed SQL name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScheduledSqlState.__new__(_ScheduledSqlState)

        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["project"] = project
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["scheduled_sql_configuration"] = scheduled_sql_configuration
        __props__.__dict__["scheduled_sql_name"] = scheduled_sql_name
        return ScheduledSql(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Task Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        Task Display Name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        Log project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output['outputs.ScheduledSqlSchedule']:
        """
        The scheduling type is generally not required by default. If there is a strong timing requirement, if it must be imported every Monday at 8 o'clock, cron can be used. See `schedule` below.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="scheduledSqlConfiguration")
    def scheduled_sql_configuration(self) -> pulumi.Output['outputs.ScheduledSqlScheduledSqlConfiguration']:
        """
        Task Configuration. See `scheduled_sql_configuration` below.
        """
        return pulumi.get(self, "scheduled_sql_configuration")

    @property
    @pulumi.getter(name="scheduledSqlName")
    def scheduled_sql_name(self) -> pulumi.Output[str]:
        """
        Timed SQL name.
        """
        return pulumi.get(self, "scheduled_sql_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EnterpriseProxyArgs', 'EnterpriseProxy']

@pulumi.input_type
class EnterpriseProxyArgs:
    def __init__(__self__, *,
                 instance_id: pulumi.Input[str],
                 password: pulumi.Input[str],
                 username: pulumi.Input[str],
                 tid: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EnterpriseProxy resource.
        :param pulumi.Input[str] instance_id: The ID of the database instance.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[str] username: The username of the database account.
        :param pulumi.Input[str] tid: The ID of the tenant.
        """
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "username", username)
        if tid is not None:
            pulumi.set(__self__, "tid", tid)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The username of the database account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def tid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the tenant.
        """
        return pulumi.get(self, "tid")

    @tid.setter
    def tid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tid", value)


@pulumi.input_type
class _EnterpriseProxyState:
    def __init__(__self__, *,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EnterpriseProxy resources.
        :param pulumi.Input[str] instance_id: The ID of the database instance.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[str] tid: The ID of the tenant.
        :param pulumi.Input[str] username: The username of the database account.
        """
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if tid is not None:
            pulumi.set(__self__, "tid", tid)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def tid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the tenant.
        """
        return pulumi.get(self, "tid")

    @tid.setter
    def tid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tid", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The username of the database account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class EnterpriseProxy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a DMS Enterprise Proxy resource.

        For information about DMS Enterprise Proxy and how to use it, see [What is Proxy](https://next.api.alibabacloud.com/document/dms-enterprise/2018-11-01/CreateProxy).

        > **NOTE:** Available since v1.188.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        current = alicloud.get_account()
        default = alicloud.get_regions(current=True)
        default_get_user_tenants = alicloud.dms.get_user_tenants(status="ACTIVE")
        default_get_zones = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="HighAvailability",
            db_instance_storage_type="cloud_essd")
        default_get_instance_classes = alicloud.rds.get_instance_classes(zone_id=default_get_zones.zones[1].id,
            engine="MySQL",
            engine_version="8.0",
            category="HighAvailability",
            db_instance_storage_type="cloud_essd",
            instance_charge_type="PostPaid")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default_get_zones.zones[1].id)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="cloud_essd",
            instance_type=default_get_instance_classes.instance_classes[0].instance_class,
            instance_storage=default_get_instance_classes.instance_classes[0].storage_range.min,
            vswitch_id=default_switch.id,
            instance_name=name,
            security_ips=[
                "100.104.5.0/24",
                "192.168.0.6",
            ],
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_account = alicloud.rds.Account("default",
            db_instance_id=default_instance.id,
            account_name="tfexamplename",
            account_password="Example12345",
            account_type="Normal")
        default_enterprise_instance = alicloud.dms.EnterpriseInstance("default",
            tid=default_get_user_tenants.ids[0],
            instance_type="mysql",
            instance_source="RDS",
            network_type="VPC",
            env_type="dev",
            host=default_instance.connection_string,
            port=3306,
            database_user=default_account.account_name,
            database_password=default_account.account_password,
            instance_name=name,
            dba_uid=current.id,
            safe_rule="自由操作",
            query_timeout=60,
            export_timeout=600,
            ecs_region=default.regions[0].id)
        default_enterprise_proxy = alicloud.dms.EnterpriseProxy("default",
            instance_id=default_enterprise_instance.instance_id,
            password="Example12345",
            username="tfexamplename",
            tid=default_get_user_tenants.ids[0])
        ```

        ## Import

        DMS Enterprise Proxy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseProxy:EnterpriseProxy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the database instance.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[str] tid: The ID of the tenant.
        :param pulumi.Input[str] username: The username of the database account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnterpriseProxyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DMS Enterprise Proxy resource.

        For information about DMS Enterprise Proxy and how to use it, see [What is Proxy](https://next.api.alibabacloud.com/document/dms-enterprise/2018-11-01/CreateProxy).

        > **NOTE:** Available since v1.188.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        current = alicloud.get_account()
        default = alicloud.get_regions(current=True)
        default_get_user_tenants = alicloud.dms.get_user_tenants(status="ACTIVE")
        default_get_zones = alicloud.rds.get_zones(engine="MySQL",
            engine_version="8.0",
            instance_charge_type="PostPaid",
            category="HighAvailability",
            db_instance_storage_type="cloud_essd")
        default_get_instance_classes = alicloud.rds.get_instance_classes(zone_id=default_get_zones.zones[1].id,
            engine="MySQL",
            engine_version="8.0",
            category="HighAvailability",
            db_instance_storage_type="cloud_essd",
            instance_charge_type="PostPaid")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="10.4.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vswitch_name=name,
            cidr_block="10.4.0.0/24",
            vpc_id=default_network.id,
            zone_id=default_get_zones.zones[1].id)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="8.0",
            db_instance_storage_type="cloud_essd",
            instance_type=default_get_instance_classes.instance_classes[0].instance_class,
            instance_storage=default_get_instance_classes.instance_classes[0].storage_range.min,
            vswitch_id=default_switch.id,
            instance_name=name,
            security_ips=[
                "100.104.5.0/24",
                "192.168.0.6",
            ],
            tags={
                "Created": "TF",
                "For": "example",
            })
        default_account = alicloud.rds.Account("default",
            db_instance_id=default_instance.id,
            account_name="tfexamplename",
            account_password="Example12345",
            account_type="Normal")
        default_enterprise_instance = alicloud.dms.EnterpriseInstance("default",
            tid=default_get_user_tenants.ids[0],
            instance_type="mysql",
            instance_source="RDS",
            network_type="VPC",
            env_type="dev",
            host=default_instance.connection_string,
            port=3306,
            database_user=default_account.account_name,
            database_password=default_account.account_password,
            instance_name=name,
            dba_uid=current.id,
            safe_rule="自由操作",
            query_timeout=60,
            export_timeout=600,
            ecs_region=default.regions[0].id)
        default_enterprise_proxy = alicloud.dms.EnterpriseProxy("default",
            instance_id=default_enterprise_instance.instance_id,
            password="Example12345",
            username="tfexamplename",
            tid=default_get_user_tenants.ids[0])
        ```

        ## Import

        DMS Enterprise Proxy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseProxy:EnterpriseProxy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EnterpriseProxyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnterpriseProxyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnterpriseProxyArgs.__new__(EnterpriseProxyArgs)

            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["tid"] = tid
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = None if username is None else pulumi.Output.secret(username)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password", "username"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(EnterpriseProxy, __self__).__init__(
            'alicloud:dms/enterpriseProxy:EnterpriseProxy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            tid: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'EnterpriseProxy':
        """
        Get an existing EnterpriseProxy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] instance_id: The ID of the database instance.
        :param pulumi.Input[str] password: The password of the database account.
        :param pulumi.Input[str] tid: The ID of the tenant.
        :param pulumi.Input[str] username: The username of the database account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnterpriseProxyState.__new__(_EnterpriseProxyState)

        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["password"] = password
        __props__.__dict__["tid"] = tid
        __props__.__dict__["username"] = username
        return EnterpriseProxy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the database instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        The password of the database account.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def tid(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the tenant.
        """
        return pulumi.get(self, "tid")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        The username of the database account.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['V3TriggerArgs', 'V3Trigger']

@pulumi.input_type
class V3TriggerArgs:
    def __init__(__self__, *,
                 function_name: pulumi.Input[str],
                 qualifier: pulumi.Input[str],
                 trigger_type: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 invocation_role: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_config: Optional[pulumi.Input[str]] = None,
                 trigger_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a V3Trigger resource.
        :param pulumi.Input[str] function_name: Function Name
        :param pulumi.Input[str] qualifier: The version or alias of the function
        :param pulumi.Input[str] trigger_type: The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        :param pulumi.Input[str] description: Description of the trigger
        :param pulumi.Input[str] invocation_role: The role required by the event source (such as OSS) to call the function.
        :param pulumi.Input[str] source_arn: Trigger Event source ARN
        :param pulumi.Input[str] trigger_config: Trigger configuration. The configuration varies for different types of triggers.
        :param pulumi.Input[str] trigger_name: Trigger Name
        """
        pulumi.set(__self__, "function_name", function_name)
        pulumi.set(__self__, "qualifier", qualifier)
        pulumi.set(__self__, "trigger_type", trigger_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if invocation_role is not None:
            pulumi.set(__self__, "invocation_role", invocation_role)
        if source_arn is not None:
            pulumi.set(__self__, "source_arn", source_arn)
        if trigger_config is not None:
            pulumi.set(__self__, "trigger_config", trigger_config)
        if trigger_name is not None:
            pulumi.set(__self__, "trigger_name", trigger_name)

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Input[str]:
        """
        Function Name
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "function_name", value)

    @property
    @pulumi.getter
    def qualifier(self) -> pulumi.Input[str]:
        """
        The version or alias of the function
        """
        return pulumi.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: pulumi.Input[str]):
        pulumi.set(self, "qualifier", value)

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> pulumi.Input[str]:
        """
        The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        return pulumi.get(self, "trigger_type")

    @trigger_type.setter
    def trigger_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "trigger_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the trigger
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="invocationRole")
    def invocation_role(self) -> Optional[pulumi.Input[str]]:
        """
        The role required by the event source (such as OSS) to call the function.
        """
        return pulumi.get(self, "invocation_role")

    @invocation_role.setter
    def invocation_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invocation_role", value)

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger Event source ARN
        """
        return pulumi.get(self, "source_arn")

    @source_arn.setter
    def source_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_arn", value)

    @property
    @pulumi.getter(name="triggerConfig")
    def trigger_config(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger configuration. The configuration varies for different types of triggers.
        """
        return pulumi.get(self, "trigger_config")

    @trigger_config.setter
    def trigger_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_config", value)

    @property
    @pulumi.getter(name="triggerName")
    def trigger_name(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger Name
        """
        return pulumi.get(self, "trigger_name")

    @trigger_name.setter
    def trigger_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_name", value)


@pulumi.input_type
class _V3TriggerState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 http_trigger: Optional[pulumi.Input['V3TriggerHttpTriggerArgs']] = None,
                 invocation_role: Optional[pulumi.Input[str]] = None,
                 last_modified_time: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 target_arn: Optional[pulumi.Input[str]] = None,
                 trigger_config: Optional[pulumi.Input[str]] = None,
                 trigger_id: Optional[pulumi.Input[str]] = None,
                 trigger_name: Optional[pulumi.Input[str]] = None,
                 trigger_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering V3Trigger resources.
        :param pulumi.Input[str] create_time: Creation time
        :param pulumi.Input[str] description: Description of the trigger
        :param pulumi.Input[str] function_name: Function Name
        :param pulumi.Input['V3TriggerHttpTriggerArgs'] http_trigger: (Available since v1.234.0) HTTP trigger information
        :param pulumi.Input[str] invocation_role: The role required by the event source (such as OSS) to call the function.
        :param pulumi.Input[str] last_modified_time: (Available since v1.234.0) The last modified time of the trigger
        :param pulumi.Input[str] qualifier: The version or alias of the function
        :param pulumi.Input[str] source_arn: Trigger Event source ARN
        :param pulumi.Input[str] status: The state of the trigger
        :param pulumi.Input[str] target_arn: (Available since v1.234.0) Resource identity of the function
        :param pulumi.Input[str] trigger_config: Trigger configuration. The configuration varies for different types of triggers.
        :param pulumi.Input[str] trigger_id: (Available since v1.234.0) Trigger ID
        :param pulumi.Input[str] trigger_name: Trigger Name
        :param pulumi.Input[str] trigger_type: The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if function_name is not None:
            pulumi.set(__self__, "function_name", function_name)
        if http_trigger is not None:
            pulumi.set(__self__, "http_trigger", http_trigger)
        if invocation_role is not None:
            pulumi.set(__self__, "invocation_role", invocation_role)
        if last_modified_time is not None:
            pulumi.set(__self__, "last_modified_time", last_modified_time)
        if qualifier is not None:
            pulumi.set(__self__, "qualifier", qualifier)
        if source_arn is not None:
            pulumi.set(__self__, "source_arn", source_arn)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target_arn is not None:
            pulumi.set(__self__, "target_arn", target_arn)
        if trigger_config is not None:
            pulumi.set(__self__, "trigger_config", trigger_config)
        if trigger_id is not None:
            pulumi.set(__self__, "trigger_id", trigger_id)
        if trigger_name is not None:
            pulumi.set(__self__, "trigger_name", trigger_name)
        if trigger_type is not None:
            pulumi.set(__self__, "trigger_type", trigger_type)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the trigger
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> Optional[pulumi.Input[str]]:
        """
        Function Name
        """
        return pulumi.get(self, "function_name")

    @function_name.setter
    def function_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "function_name", value)

    @property
    @pulumi.getter(name="httpTrigger")
    def http_trigger(self) -> Optional[pulumi.Input['V3TriggerHttpTriggerArgs']]:
        """
        (Available since v1.234.0) HTTP trigger information
        """
        return pulumi.get(self, "http_trigger")

    @http_trigger.setter
    def http_trigger(self, value: Optional[pulumi.Input['V3TriggerHttpTriggerArgs']]):
        pulumi.set(self, "http_trigger", value)

    @property
    @pulumi.getter(name="invocationRole")
    def invocation_role(self) -> Optional[pulumi.Input[str]]:
        """
        The role required by the event source (such as OSS) to call the function.
        """
        return pulumi.get(self, "invocation_role")

    @invocation_role.setter
    def invocation_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invocation_role", value)

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.234.0) The last modified time of the trigger
        """
        return pulumi.get(self, "last_modified_time")

    @last_modified_time.setter
    def last_modified_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_modified_time", value)

    @property
    @pulumi.getter
    def qualifier(self) -> Optional[pulumi.Input[str]]:
        """
        The version or alias of the function
        """
        return pulumi.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "qualifier", value)

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger Event source ARN
        """
        return pulumi.get(self, "source_arn")

    @source_arn.setter
    def source_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_arn", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the trigger
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="targetArn")
    def target_arn(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.234.0) Resource identity of the function
        """
        return pulumi.get(self, "target_arn")

    @target_arn.setter
    def target_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_arn", value)

    @property
    @pulumi.getter(name="triggerConfig")
    def trigger_config(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger configuration. The configuration varies for different types of triggers.
        """
        return pulumi.get(self, "trigger_config")

    @trigger_config.setter
    def trigger_config(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_config", value)

    @property
    @pulumi.getter(name="triggerId")
    def trigger_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.234.0) Trigger ID
        """
        return pulumi.get(self, "trigger_id")

    @trigger_id.setter
    def trigger_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_id", value)

    @property
    @pulumi.getter(name="triggerName")
    def trigger_name(self) -> Optional[pulumi.Input[str]]:
        """
        Trigger Name
        """
        return pulumi.get(self, "trigger_name")

    @trigger_name.setter
    def trigger_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_name", value)

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        return pulumi.get(self, "trigger_type")

    @trigger_type.setter
    def trigger_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "trigger_type", value)


class V3Trigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 invocation_role: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_config: Optional[pulumi.Input[str]] = None,
                 trigger_name: Optional[pulumi.Input[str]] = None,
                 trigger_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a FCV3 Trigger resource.

        A trigger is a way of triggering the execution of a function. In the event-driven computing model, the event source is the producer of the event, the function is the handler of the event, and the trigger provides a centralized and unified way to manage different event sources. In the event source, when the event occurs, if the rules defined by the trigger are met,.

        For information about FCV3 Trigger and how to use it, see [What is Trigger](https://www.alibabacloud.com/help/en/functioncompute/api-fc-2023-03-30-createtrigger).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        function_name = config.get("functionName")
        if function_name is None:
            function_name = "TerraformTriggerResourceAPI"
        trigger_name = config.get("triggerName")
        if trigger_name is None:
            trigger_name = "TerraformTrigger_CDN"
        function = alicloud.fc.V3Function("function",
            memory_size=512,
            cpu=0.5,
            handler="index.Handler",
            code={
                "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
            },
            function_name=name,
            runtime="python3.9",
            disk_size=512,
            log_config={
                "log_begin_rule": "None",
            })
        current = alicloud.get_account()
        default = alicloud.fc.V3Trigger("default",
            trigger_type="cdn_events",
            trigger_name=name,
            description="create",
            qualifier="LATEST",
            trigger_config=json.dumps({
                "eventName": "CachedObjectsPushed",
                "eventVersion": "1.0.0",
                "notes": "example",
                "filter": {
                    "domain": ["example.com"],
                },
            }),
            source_arn=f"acs:cdn:*:{current.id}",
            invocation_role=f"acs:ram::{current.id}:role/aliyuncdneventnotificationrole",
            function_name=function.function_name)
        ```

        ## Import

        FCV3 Trigger can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:fc/v3Trigger:V3Trigger example <function_name>:<trigger_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the trigger
        :param pulumi.Input[str] function_name: Function Name
        :param pulumi.Input[str] invocation_role: The role required by the event source (such as OSS) to call the function.
        :param pulumi.Input[str] qualifier: The version or alias of the function
        :param pulumi.Input[str] source_arn: Trigger Event source ARN
        :param pulumi.Input[str] trigger_config: Trigger configuration. The configuration varies for different types of triggers.
        :param pulumi.Input[str] trigger_name: Trigger Name
        :param pulumi.Input[str] trigger_type: The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: V3TriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a FCV3 Trigger resource.

        A trigger is a way of triggering the execution of a function. In the event-driven computing model, the event source is the producer of the event, the function is the handler of the event, and the trigger provides a centralized and unified way to manage different event sources. In the event source, when the event occurs, if the rules defined by the trigger are met,.

        For information about FCV3 Trigger and how to use it, see [What is Trigger](https://www.alibabacloud.com/help/en/functioncompute/api-fc-2023-03-30-createtrigger).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        function_name = config.get("functionName")
        if function_name is None:
            function_name = "TerraformTriggerResourceAPI"
        trigger_name = config.get("triggerName")
        if trigger_name is None:
            trigger_name = "TerraformTrigger_CDN"
        function = alicloud.fc.V3Function("function",
            memory_size=512,
            cpu=0.5,
            handler="index.Handler",
            code={
                "zip_file": "UEsDBBQACAAIAAAAAAAAAAAAAAAAAAAAAAAIAAAAaW5kZXgucHmEkEFKxEAQRfd9ig9ZTCJOooIwDMwNXLqXnnQlaalUhU5lRj2KZ/FOXkESGR114bJ/P/7jV4b1xRq1hijtFpM1682cuNgPmgysbRulPT0fRxXnMtwrSPyeCdYRokSLnuMLJTTkbUqEvDMbxm1VdcRD6Tk+T1LW2ldB66knsYdA5iNX17ebm6tN2VnPhcswMPmREPuBacb+CiapLarAj9gT6/H97dVlCNScY3mtYvRkxdZlwDKDEnanPWVLdrdkeXEGlFEazVdfPVHaVeHc3N15CUwppwOJXeK7HshAB8NuOU7J6sP4SRXuH/EvbUfMiqMmDqv5M5FNSfAj/wgAAP//UEsHCPl//NYAAQAArwEAAFBLAQIUABQACAAIAAAAAAD5f/zWAAEAAK8BAAAIAAAAAAAAAAAAAAAAAAAAAABpbmRleC5weVBLBQYAAAAAAQABADYAAAA2AQAAAAA=",
            },
            function_name=name,
            runtime="python3.9",
            disk_size=512,
            log_config={
                "log_begin_rule": "None",
            })
        current = alicloud.get_account()
        default = alicloud.fc.V3Trigger("default",
            trigger_type="cdn_events",
            trigger_name=name,
            description="create",
            qualifier="LATEST",
            trigger_config=json.dumps({
                "eventName": "CachedObjectsPushed",
                "eventVersion": "1.0.0",
                "notes": "example",
                "filter": {
                    "domain": ["example.com"],
                },
            }),
            source_arn=f"acs:cdn:*:{current.id}",
            invocation_role=f"acs:ram::{current.id}:role/aliyuncdneventnotificationrole",
            function_name=function.function_name)
        ```

        ## Import

        FCV3 Trigger can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:fc/v3Trigger:V3Trigger example <function_name>:<trigger_name>
        ```

        :param str resource_name: The name of the resource.
        :param V3TriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(V3TriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 function_name: Optional[pulumi.Input[str]] = None,
                 invocation_role: Optional[pulumi.Input[str]] = None,
                 qualifier: Optional[pulumi.Input[str]] = None,
                 source_arn: Optional[pulumi.Input[str]] = None,
                 trigger_config: Optional[pulumi.Input[str]] = None,
                 trigger_name: Optional[pulumi.Input[str]] = None,
                 trigger_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = V3TriggerArgs.__new__(V3TriggerArgs)

            __props__.__dict__["description"] = description
            if function_name is None and not opts.urn:
                raise TypeError("Missing required property 'function_name'")
            __props__.__dict__["function_name"] = function_name
            __props__.__dict__["invocation_role"] = invocation_role
            if qualifier is None and not opts.urn:
                raise TypeError("Missing required property 'qualifier'")
            __props__.__dict__["qualifier"] = qualifier
            __props__.__dict__["source_arn"] = source_arn
            __props__.__dict__["trigger_config"] = trigger_config
            __props__.__dict__["trigger_name"] = trigger_name
            if trigger_type is None and not opts.urn:
                raise TypeError("Missing required property 'trigger_type'")
            __props__.__dict__["trigger_type"] = trigger_type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["http_trigger"] = None
            __props__.__dict__["last_modified_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["target_arn"] = None
            __props__.__dict__["trigger_id"] = None
        super(V3Trigger, __self__).__init__(
            'alicloud:fc/v3Trigger:V3Trigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            function_name: Optional[pulumi.Input[str]] = None,
            http_trigger: Optional[pulumi.Input[Union['V3TriggerHttpTriggerArgs', 'V3TriggerHttpTriggerArgsDict']]] = None,
            invocation_role: Optional[pulumi.Input[str]] = None,
            last_modified_time: Optional[pulumi.Input[str]] = None,
            qualifier: Optional[pulumi.Input[str]] = None,
            source_arn: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            target_arn: Optional[pulumi.Input[str]] = None,
            trigger_config: Optional[pulumi.Input[str]] = None,
            trigger_id: Optional[pulumi.Input[str]] = None,
            trigger_name: Optional[pulumi.Input[str]] = None,
            trigger_type: Optional[pulumi.Input[str]] = None) -> 'V3Trigger':
        """
        Get an existing V3Trigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Creation time
        :param pulumi.Input[str] description: Description of the trigger
        :param pulumi.Input[str] function_name: Function Name
        :param pulumi.Input[Union['V3TriggerHttpTriggerArgs', 'V3TriggerHttpTriggerArgsDict']] http_trigger: (Available since v1.234.0) HTTP trigger information
        :param pulumi.Input[str] invocation_role: The role required by the event source (such as OSS) to call the function.
        :param pulumi.Input[str] last_modified_time: (Available since v1.234.0) The last modified time of the trigger
        :param pulumi.Input[str] qualifier: The version or alias of the function
        :param pulumi.Input[str] source_arn: Trigger Event source ARN
        :param pulumi.Input[str] status: The state of the trigger
        :param pulumi.Input[str] target_arn: (Available since v1.234.0) Resource identity of the function
        :param pulumi.Input[str] trigger_config: Trigger configuration. The configuration varies for different types of triggers.
        :param pulumi.Input[str] trigger_id: (Available since v1.234.0) Trigger ID
        :param pulumi.Input[str] trigger_name: Trigger Name
        :param pulumi.Input[str] trigger_type: The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _V3TriggerState.__new__(_V3TriggerState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["function_name"] = function_name
        __props__.__dict__["http_trigger"] = http_trigger
        __props__.__dict__["invocation_role"] = invocation_role
        __props__.__dict__["last_modified_time"] = last_modified_time
        __props__.__dict__["qualifier"] = qualifier
        __props__.__dict__["source_arn"] = source_arn
        __props__.__dict__["status"] = status
        __props__.__dict__["target_arn"] = target_arn
        __props__.__dict__["trigger_config"] = trigger_config
        __props__.__dict__["trigger_id"] = trigger_id
        __props__.__dict__["trigger_name"] = trigger_name
        __props__.__dict__["trigger_type"] = trigger_type
        return V3Trigger(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Creation time
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the trigger
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="functionName")
    def function_name(self) -> pulumi.Output[str]:
        """
        Function Name
        """
        return pulumi.get(self, "function_name")

    @property
    @pulumi.getter(name="httpTrigger")
    def http_trigger(self) -> pulumi.Output['outputs.V3TriggerHttpTrigger']:
        """
        (Available since v1.234.0) HTTP trigger information
        """
        return pulumi.get(self, "http_trigger")

    @property
    @pulumi.getter(name="invocationRole")
    def invocation_role(self) -> pulumi.Output[Optional[str]]:
        """
        The role required by the event source (such as OSS) to call the function.
        """
        return pulumi.get(self, "invocation_role")

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> pulumi.Output[str]:
        """
        (Available since v1.234.0) The last modified time of the trigger
        """
        return pulumi.get(self, "last_modified_time")

    @property
    @pulumi.getter
    def qualifier(self) -> pulumi.Output[str]:
        """
        The version or alias of the function
        """
        return pulumi.get(self, "qualifier")

    @property
    @pulumi.getter(name="sourceArn")
    def source_arn(self) -> pulumi.Output[Optional[str]]:
        """
        Trigger Event source ARN
        """
        return pulumi.get(self, "source_arn")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The state of the trigger
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="targetArn")
    def target_arn(self) -> pulumi.Output[str]:
        """
        (Available since v1.234.0) Resource identity of the function
        """
        return pulumi.get(self, "target_arn")

    @property
    @pulumi.getter(name="triggerConfig")
    def trigger_config(self) -> pulumi.Output[Optional[str]]:
        """
        Trigger configuration. The configuration varies for different types of triggers.
        """
        return pulumi.get(self, "trigger_config")

    @property
    @pulumi.getter(name="triggerId")
    def trigger_id(self) -> pulumi.Output[str]:
        """
        (Available since v1.234.0) Trigger ID
        """
        return pulumi.get(self, "trigger_id")

    @property
    @pulumi.getter(name="triggerName")
    def trigger_name(self) -> pulumi.Output[str]:
        """
        Trigger Name
        """
        return pulumi.get(self, "trigger_name")

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> pulumi.Output[str]:
        """
        The type of the trigger. Currently, the supported types include oss, log, http, timer, tablestore, cdn_events, mns_topic and eventbridge.
        """
        return pulumi.get(self, "trigger_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServiceHybridDoubleWriteArgs', 'ServiceHybridDoubleWrite']

@pulumi.input_type
class ServiceHybridDoubleWriteArgs:
    def __init__(__self__, *,
                 namespace: pulumi.Input[str],
                 source_namespace: pulumi.Input[str],
                 source_user_id: pulumi.Input[str],
                 user_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ServiceHybridDoubleWrite resource.
        :param pulumi.Input[str] namespace: Target Namespace.
        :param pulumi.Input[str] source_namespace: Source Namespace.
        :param pulumi.Input[str] source_user_id: Source UserId.
        :param pulumi.Input[str] user_id: Target UserId.
        """
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "source_namespace", source_namespace)
        pulumi.set(__self__, "source_user_id", source_user_id)
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        Target Namespace.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="sourceNamespace")
    def source_namespace(self) -> pulumi.Input[str]:
        """
        Source Namespace.
        """
        return pulumi.get(self, "source_namespace")

    @source_namespace.setter
    def source_namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_namespace", value)

    @property
    @pulumi.getter(name="sourceUserId")
    def source_user_id(self) -> pulumi.Input[str]:
        """
        Source UserId.
        """
        return pulumi.get(self, "source_user_id")

    @source_user_id.setter
    def source_user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_user_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        Target UserId.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _ServiceHybridDoubleWriteState:
    def __init__(__self__, *,
                 namespace: Optional[pulumi.Input[str]] = None,
                 source_namespace: Optional[pulumi.Input[str]] = None,
                 source_user_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ServiceHybridDoubleWrite resources.
        :param pulumi.Input[str] namespace: Target Namespace.
        :param pulumi.Input[str] source_namespace: Source Namespace.
        :param pulumi.Input[str] source_user_id: Source UserId.
        :param pulumi.Input[str] user_id: Target UserId.
        """
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if source_namespace is not None:
            pulumi.set(__self__, "source_namespace", source_namespace)
        if source_user_id is not None:
            pulumi.set(__self__, "source_user_id", source_user_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Target Namespace.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="sourceNamespace")
    def source_namespace(self) -> Optional[pulumi.Input[str]]:
        """
        Source Namespace.
        """
        return pulumi.get(self, "source_namespace")

    @source_namespace.setter
    def source_namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_namespace", value)

    @property
    @pulumi.getter(name="sourceUserId")
    def source_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        Source UserId.
        """
        return pulumi.get(self, "source_user_id")

    @source_user_id.setter
    def source_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_user_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        Target UserId.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class ServiceHybridDoubleWrite(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 source_namespace: Optional[pulumi.Input[str]] = None,
                 source_user_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Monitor Service Hybrid Double Write resource.

        For information about Cloud Monitor Service Hybrid Double Write and how to use it, see [What is Hybrid Double Write](https://next.api.alibabacloud.com/document/Cms/2018-03-08/CreateHybridDoubleWrite).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_account()
        source = alicloud.cms.Namespace("source", namespace=name)
        default_namespace = alicloud.cms.Namespace("default", namespace=f"{name}-source")
        default_service_hybrid_double_write = alicloud.cloudmonitor.ServiceHybridDoubleWrite("default",
            source_namespace=source.id,
            source_user_id=default.id,
            namespace=default_namespace.id,
            user_id=default.id)
        ```

        ## Import

        Cloud Monitor Service Hybrid Double Write can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudmonitor/serviceHybridDoubleWrite:ServiceHybridDoubleWrite example <source_namespace>:<source_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] namespace: Target Namespace.
        :param pulumi.Input[str] source_namespace: Source Namespace.
        :param pulumi.Input[str] source_user_id: Source UserId.
        :param pulumi.Input[str] user_id: Target UserId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceHybridDoubleWriteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Monitor Service Hybrid Double Write resource.

        For information about Cloud Monitor Service Hybrid Double Write and how to use it, see [What is Hybrid Double Write](https://next.api.alibabacloud.com/document/Cms/2018-03-08/CreateHybridDoubleWrite).

        > **NOTE:** Available since v1.210.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.get_account()
        source = alicloud.cms.Namespace("source", namespace=name)
        default_namespace = alicloud.cms.Namespace("default", namespace=f"{name}-source")
        default_service_hybrid_double_write = alicloud.cloudmonitor.ServiceHybridDoubleWrite("default",
            source_namespace=source.id,
            source_user_id=default.id,
            namespace=default_namespace.id,
            user_id=default.id)
        ```

        ## Import

        Cloud Monitor Service Hybrid Double Write can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudmonitor/serviceHybridDoubleWrite:ServiceHybridDoubleWrite example <source_namespace>:<source_user_id>
        ```

        :param str resource_name: The name of the resource.
        :param ServiceHybridDoubleWriteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceHybridDoubleWriteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 source_namespace: Optional[pulumi.Input[str]] = None,
                 source_user_id: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceHybridDoubleWriteArgs.__new__(ServiceHybridDoubleWriteArgs)

            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            if source_namespace is None and not opts.urn:
                raise TypeError("Missing required property 'source_namespace'")
            __props__.__dict__["source_namespace"] = source_namespace
            if source_user_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_user_id'")
            __props__.__dict__["source_user_id"] = source_user_id
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(ServiceHybridDoubleWrite, __self__).__init__(
            'alicloud:cloudmonitor/serviceHybridDoubleWrite:ServiceHybridDoubleWrite',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            source_namespace: Optional[pulumi.Input[str]] = None,
            source_user_id: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'ServiceHybridDoubleWrite':
        """
        Get an existing ServiceHybridDoubleWrite resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] namespace: Target Namespace.
        :param pulumi.Input[str] source_namespace: Source Namespace.
        :param pulumi.Input[str] source_user_id: Source UserId.
        :param pulumi.Input[str] user_id: Target UserId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceHybridDoubleWriteState.__new__(_ServiceHybridDoubleWriteState)

        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["source_namespace"] = source_namespace
        __props__.__dict__["source_user_id"] = source_user_id
        __props__.__dict__["user_id"] = user_id
        return ServiceHybridDoubleWrite(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        Target Namespace.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="sourceNamespace")
    def source_namespace(self) -> pulumi.Output[str]:
        """
        Source Namespace.
        """
        return pulumi.get(self, "source_namespace")

    @property
    @pulumi.getter(name="sourceUserId")
    def source_user_id(self) -> pulumi.Output[str]:
        """
        Source UserId.
        """
        return pulumi.get(self, "source_user_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        Target UserId.
        """
        return pulumi.get(self, "user_id")

